Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ReleaseFields = []string{
"apiUrl",
"author",
"assets",
"body",
"createdAt",
"databaseId",
"id",
"isDraft",
"isPrerelease",
"name",
"publishedAt",
"tagName",
"tarballUrl",
"targetCommitish",
"uploadUrl",
"url",
"zipballUrl",
}
Functions ¶
func ConcurrentUpload ¶
func ConcurrentUpload(httpClient httpDoer, uploadURL string, numWorkers int, assets []*AssetForUpload) error
Types ¶
type AssetForUpload ¶
type AssetForUpload struct {
Name string
Label string
Size int64
MIMEType string
Open func() (io.ReadCloser, error)
ExistingURL string
}
func AssetsFromArgs ¶
func AssetsFromArgs(args []string) (assets []*AssetForUpload, err error)
type Release ¶
type Release struct {
DatabaseID int64 `json:"id"`
ID string `json:"node_id"`
TagName string `json:"tag_name"`
Name string `json:"name"`
Body string `json:"body"`
IsDraft bool `json:"draft"`
IsPrerelease bool `json:"prerelease"`
CreatedAt time.Time `json:"created_at"`
PublishedAt *time.Time `json:"published_at"`
TargetCommitish string `json:"target_commitish"`
APIURL string `json:"url"`
UploadURL string `json:"upload_url"`
TarballURL string `json:"tarball_url"`
ZipballURL string `json:"zipball_url"`
URL string `json:"html_url"`
Assets []ReleaseAsset
Author struct {
ID string `json:"node_id"`
Login string `json:"login"`
}
}
func FetchLatestRelease ¶
func FetchLatestRelease(ctx context.Context, httpClient *http.Client, repo ghrepo.Interface) (*Release, error)
FetchLatestRelease finds the latest published release for a repository.
func FetchRelease ¶
func FetchRelease(ctx context.Context, httpClient *http.Client, repo ghrepo.Interface, tagName string) (*Release, error)
FetchRelease finds a published repository release by its tagName, or a draft release by its pending tag name.
func (*Release) ExportData ¶
type ReleaseAsset ¶
type ReleaseAsset struct {
ID string `json:"node_id"`
Name string
Label string
Size int64
State string
APIURL string `json:"url"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
DownloadCount int `json:"download_count"`
ContentType string `json:"content_type"`
BrowserDownloadURL string `json:"browser_download_url"`
}
Click to show internal directories.
Click to hide internal directories.